]> ruderich.org/simon Gitweb - config/dotfiles.git/blobdiff - lib.sh
lib.sh: Add support for FreeBSD to os().
[config/dotfiles.git] / lib.sh
diff --git a/lib.sh b/lib.sh
index 9d79b65b1d39524ec3a2b84f05d13cb002fd4f5b..206f9954a3841041da04e8b4417dccf497b889dc 100644 (file)
--- a/lib.sh
+++ b/lib.sh
@@ -4,19 +4,23 @@
 
 
 # csh gives the error "Unknown colorls variable `su'." when used with newer
-# options supported by zsh or GNU ls.
+# options supported by Zsh or GNU ls.
 unset LS_COLORS
 
 
 # Check if the given program is installed. Returns 0 if it exists, 1
 # otherwise; so it can be used in if.
 installed() {
-    which $1 | grep -E '^/' > /dev/null
+    [ x`which $1 2>&1 | cut -c 1` = x/ ] || return 1
 }
 
# Prints the current OS. Supported are Debian (debian), Gentoo (gentoo) and
# Mac OS X (darwin) at the moment. If an unsupported OS is used an error is
# printed.
 os() {
     if [ -f /etc/debian_version ]; then
         echo debian
@@ -24,13 +28,17 @@ os() {
         echo gentoo
     elif [ x`uname` = xDarwin ]; then
         echo darwin
+    elif [ x`uname` = xSunOS ]; then
+        echo sun
+    elif [ x`uname` = xFreeBSD ]; then
+        echo freebsd
     else
         echo unsupported OS! >&2
         return 1
     fi
 }
 
-# Creates a symbolic link for file $1 in dirname of $2 with name of basenmae
+# Creates a symbolic link for file $1 in dirname of $2 with name of basename
 # $2.
 #
 # `./link.sh example ~/.examplerc` creates a symbolic link to example
@@ -38,7 +46,8 @@ os() {
 link() {
     # Get all necessary paths.
     pwd=`pwd`
-    base=`dirname "$2"`
+    base=`echo "$2" | sed "s|\~|$HOME|"` # expand ~, some sh don't do it
+    base=`dirname "$base"`
     source=`echo "$pwd/$1" | sed "s|$base/||"`
     target=`basename "$2"`
 
@@ -47,13 +56,14 @@ link() {
 
     # Abort if the target file exists and is no symbolic link. Prevents
     # overwriting real files.
-    if [ -e "$target" -a ! -h "$target" ]; then
+    if [ \( -f "$target" -a ! -h "$target" \) -o \
+         \( -s "$target" -a ! -h "$target" \) ]; then
         echo "link(): target '$target' exists already and is no symbolic link!" >&2
         exit 1
     fi
 
-    # Make sure the source exists.
-    if [ ! -e "$source" ]; then
+    # Make sure the source exists (is file, directory or link).
+    if [ ! -f "$source" -a ! -d "$source" -a ! -h "$source" ]; then
         echo "link(): source '$source' doesn't exist!" >&2
         exit 1
     fi
@@ -80,7 +90,7 @@ warning() {
     echo "# It was generated from $2 on `date`." >> $1
     echo >> $1
 
-    # Display given options if there were any (zsh has a problem with $options
+    # Display given options if there were any (Zsh has a problem with $options
     # as variable name).
     option=
     if [ -n "$4" ]; then
@@ -4,19 +4,23 @@
 }
 
-# Prints the current OS. Supported are Debian (debian), Gentoo (gentoo) and
-# Mac OS X (darwin) at the moment. If an unsupported OS is used an error is
-# printed.
+# Print the current OS. The following OS are supported at the moment:
+# - Debian (debian)
+# - Gentoo (gentoo)
+# - Mac OS X (darwin)
+# - Solaris/OpenSolaris (sun)
+# - FreeBSD (freebsd)
+# If an unsupported OS is used an error is printed.
 os() {
     if [ -f /etc/debian_version ]; then